Struct amazon_sp_vendor_direct_fulfillment_sandbox_test_data::models::scenario::Scenario
source · [−]Expand description
Scenario : A scenario test case response returned when the request is successful.
Fields
scenario_id: StringAn identifier that identifies the type of scenario that user can use for testing.
orders: Vec<TestOrder>A list of orders that can be used by the caller to test each life cycle or scenario.
Implementations